@@ -23,13 +23,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20373 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-06-03 13:15:06 +0000 (Tue, 03 Jun 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __CODEC_G711A1_PLC_H__
-#define __CODEC_G711A1_PLC_H__
+#ifndef OPAL_CODEC_G711A1_PLC_H
+#define OPAL_CODEC_G711A1_PLC_H
 
 #include <opal/buildopts.h>
 
@@ -113,4 +113,5 @@ class OpalG711_PLC
 
 
 #endif // OPAL_G711PLC
-#endif // __CODEC_G711A1_PLC_H__
+
+#endif // OPAL_CODEC_G711A1_PLC_H
