@@ -22,13 +22,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_RFC2833_H
-#define __OPAL_RFC2833_H
+#ifndef OPAL_CODEC_RFC2833_H
+#define OPAL_CODEC_RFC2833_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -160,7 +160,7 @@ class OpalRFC2833Proto : public PObject {
 };
 
 
-#endif // __OPAL_RFC2833_H
+#endif // OPAL_CODEC_RFC2833_H
 
 
 /////////////////////////////////////////////////////////////////////////////
