@@ -23,13 +23,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_RFC4175_H
-#define __OPAL_RFC4175_H
+#ifndef OPAL_CODEC_RFC4175_H
+#define OPAL_CODEC_RFC4175_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -231,4 +231,4 @@ class Opal_RGB24_to_RFC4175RGB : public OpalRFC4175Encoder
 
 /////////////////////////////////////////////////////////////////////////////
 
-#endif
+#endif // OPAL_CODEC_RFC4175_H
