@@ -22,13 +22,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_SILENCEDETECT_H
-#define __OPAL_SILENCEDETECT_H
+#ifndef OPAL_CODEC_SILENCEDETECT_H
+#define OPAL_CODEC_SILENCEDETECT_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -169,7 +169,7 @@ class OpalPCM16SilenceDetector : public OpalSilenceDetector
 extern ostream & operator<<(ostream & strm, OpalSilenceDetector::Mode mode);
 
 
-#endif // __OPAL_SILENCEDETECT_H
+#endif // OPAL_CODEC_SILENCEDETECT_H
 
 
 /////////////////////////////////////////////////////////////////////////////
