@@ -18,13 +18,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_H224HANDLER_H
-#define __OPAL_H224HANDLER_H
+#ifndef OPAL_H224_H224HANDLER_H
+#define OPAL_H224_H224HANDLER_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -133,5 +133,5 @@ private:
 #endif //
 
 
-#endif // __OPAL_H224HANDLER_H
+#endif // OPAL_H224_H224HANDLER_H
 
