@@ -26,18 +26,21 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20631 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-07-29 08:22:44 +0200 (mar 29 jui 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_H323CON_H
-#define __OPAL_H323CON_H
+#ifndef OPAL_H323_H323CON_H
+#define OPAL_H323_H323CON_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
 #endif
 
+#include <opal/buildopts.h>
+
+#if OPAL_H323
 
 #include <opal/rtpconn.h>
 #include <opal/guid.h>
@@ -105,7 +108,7 @@ class H45011Handler;
 
 class OpalCall;
 
-#ifdef OPAL_H460
+#if OPAL_H460
 class H460_FeatureSet;
 #endif
 
@@ -2034,7 +2037,7 @@ class H323Connection : public OpalRTPConnection
     H45011Handler                    * h45011handler;
 #endif
 
-#ifdef OPAL_H460
+#if OPAL_H460
     H460_FeatureSet * features;
 #endif
 
@@ -2046,7 +2049,9 @@ class H323Connection : public OpalRTPConnection
 PDICTIONARY(H323CallIdentityDict, PString, H323Connection);
 
 
-#endif // __OPAL_H323CON_H
+#endif // OPAL_H323
+
+#endif // OPAL_H323_H323CON_H
 
 
 /////////////////////////////////////////////////////////////////////////////
