@@ -26,13 +26,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_H323PDU_H
-#define __OPAL_H323PDU_H
+#ifndef OPAL_H323_H323PDU_H
+#define OPAL_H323_H323PDU_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -40,6 +40,8 @@
 
 #include <opal/buildopts.h>
 
+#if OPAL_H323
+
 #include <ptlib/sockets.h>
 #include <h323/h323con.h>
 #include <h323/transaddr.h>
@@ -505,7 +507,9 @@ void H323TraceDumpPDU(
 #endif
 
 
-#endif // __OPAL_H323PDU_H
+#endif // OPAL_H323
+
+#endif // OPAL_H323_H323PDU_H
 
 
 /////////////////////////////////////////////////////////////////////////////
