@@ -24,13 +24,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20527 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-07-02 12:07:41 +0000 (Wed, 02 Jul 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_LIDPLUGIN_H
-#define __OPAL_LIDPLUGIN_H
+#ifndef OPAL_LIDS_LIDPLUGIN_H
+#define OPAL_LIDS_LIDPLUGIN_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -295,4 +295,4 @@ typedef struct PluginLID_Definition * (* PluginLID_GetDefinitionsFunction)(unsig
 };
 #endif
 
-#endif // __OPAL_LIDPLUGIN_H
+#endif // OPAL_LIDS_LIDPLUGIN_H
