@@ -27,13 +27,13 @@
  *     US Joint Forces Command Joint Concept Development & Experimentation (J9)
  *     http://www.jfcom.mil/about/abt_j9.htm
  *
- * $Revision: 20722 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-08-22 08:33:16 +0200 (ven 22 aoû 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_CONNECTION_H
-#define __OPAL_CONNECTION_H
+#ifndef OPAL_OPAL_CONNECTION_H
+#define OPAL_OPAL_CONNECTION_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -279,6 +279,7 @@ class OpalProductInfo
     PString vendor;
     PString name;
     PString version;
+    PString comments;
     BYTE    t35CountryCode;
     BYTE    t35Extension;
     WORD    manufacturerCode;
@@ -1281,6 +1282,12 @@ class OpalConnection : public PSafeObject
       */
     virtual PString GetCalledPartyURL();
 
+    /* Internal function to copy party names from "network" connection to
+       "non-network" connection such as OpalPCSSConnection. This allows
+       the non-network GetRemoteAddress() function and its ilk to return
+       the intuitive value, i.e. the value from the OTHER connection.
+     */
+    void CopyPartyNames(const OpalConnection & other);
 
     /**Get the default maximum audio jitter delay parameter.
        Defaults to 50ms
@@ -1329,7 +1336,7 @@ class OpalConnection : public PSafeObject
     MediaAddressesDict & GetMediaTransportAddresses()
     { return mediaTransportAddresses; }
 
-#ifdef OPAL_STATISTICS
+#if OPAL_STATISTICS
     /**Get Video Update requests statistic.
       */
     unsigned GetVideoUpdateRequestsSent() const { return m_VideoUpdateRequestsSent; }
@@ -1378,7 +1385,7 @@ class OpalConnection : public PSafeObject
   protected:
     void OnConnectedInternal();
 
-#if P_DTMF
+#if OPAL_PTLIB_DTMF
     PDECLARE_NOTIFIER(RTP_DataFrame, OpalConnection, OnUserInputInBandDTMF);
 #endif
     PDECLARE_NOTIFIER(PThread, OpalConnection, OnReleaseThreadMain);
@@ -1432,7 +1439,7 @@ class OpalConnection : public PSafeObject
 
     // The In-Band DTMF detector. This is used inside an audio filter which is
     // added to the audio channel.
-#if P_DTMF
+#if OPAL_PTLIB_DTMF
     PDTMFDecoder        dtmfDecoder;
 #endif
 
@@ -1448,12 +1455,12 @@ class OpalConnection : public PSafeObject
     StringOptions * stringOptions;
     PString recordAudioFilename;
 
-#ifdef OPAL_STATISTICS
+#if OPAL_STATISTICS
     unsigned m_VideoUpdateRequestsSent;
 #endif
 };
 
-#endif // __OPAL_CONNECTION_H
+#endif // OPAL_OPAL_CONNECTION_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
