@@ -24,13 +24,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20448 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-06-16 06:31:46 +0200 (lun 16 jun 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_ENDPOINT_H
-#define __OPAL_ENDPOINT_H
+#ifndef OPAL_OPAL_ENDPOINT_H
+#define OPAL_OPAL_ENDPOINT_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -162,7 +162,7 @@ class OpalEndPoint : public PObject
       */
     OpalTransportAddressArray GetInterfaceAddresses(
       PBoolean excludeLocalHost = PTrue,       ///<  Flag to exclude 127.0.0.1
-      OpalTransport * associatedTransport = NULL
+      const OpalTransport * associatedTransport = NULL
                           ///<  Associated transport for precedence and translation
     );
 
@@ -674,7 +674,7 @@ class OpalEndPoint : public PObject
       OpalConnection & connection   ///< New connection just created
     );
 
-#if P_SSL
+#if OPAL_PTLIB_SSL
     PString GetSSLCertificate() const;
 #endif
 
@@ -705,7 +705,7 @@ class OpalEndPoint : public PObject
 };
 
 
-#endif // __OPAL_ENDPOINT_H
+#endif // OPAL_OPAL_ENDPOINT_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
