@@ -24,13 +24,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_MEDIAFMT_H
-#define __OPAL_MEDIAFMT_H
+#ifndef OPAL_OPAL_MEDIAFMT_H
+#define OPAL_OPAL_MEDIAFMT_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -742,19 +742,6 @@ class OpalMediaFormat : public PContainer
       */
     const char * GetEncodingName() const { PWaitAndSignal m(_mutex); return m_info == NULL ? "" : m_info->rtpEncodingName.GetPointer(); }
 
-    enum {
-      DefaultAudioSessionID = 1,
-      DefaultVideoSessionID = 2,
-      DefaultDataSessionID  = 3,
-      DefaultH224SessionID  = 4
-    };
-
-    /**DEPRECATED - Get the default session ID for media format.
-      */
-    unsigned GetDefaultSessionID() const { 
-      PWaitAndSignal m(_mutex); return m_info == NULL ? 0 : OpalMediaTypeDefinition::GetDefaultSessionId(m_info->mediaType); 
-    }
-
     /** Get the media type for this format
       */
     OpalMediaType GetMediaType() const { PWaitAndSignal m(_mutex); return m_info == NULL ? OpalMediaType() : m_info->mediaType; }
@@ -1227,7 +1214,7 @@ extern const OpalMediaFormat & GetOpalT38();
 #endif
 #endif
 
-#endif  // __OPAL_MEDIAFMT_H
+#endif  // OPAL_OPAL_MEDIAFMT_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
