@@ -24,13 +24,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_PCSS_H
-#define __OPAL_PCSS_H
+#ifndef OPAL_OPAL_PCSS_H
+#define OPAL_OPAL_PCSS_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -421,7 +421,7 @@ class OpalPCSSConnection : public OpalConnection
 
 #endif // OPAL_PTLIB_AUDIO
 
-#endif // __OPAL_PCSS_H
+#endif // OPAL_OPAL_PCSS_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
