@@ -23,13 +23,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21035 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-17 07:57:58 +0000 (Wed, 17 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_RTPCONN_H
-#define __OPAL_RTPCONN_H
+#ifndef OPAL_OPAL_RTPCONN_H
+#define OPAL_OPAL_RTPCONN_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -357,5 +357,4 @@ class OpalSecurityMode : public PObject
     virtual PBoolean Open() = 0;
 };
 
-#endif 
-
+#endif // OPAL_OPAL_RTPCONN_H
