@@ -28,13 +28,13 @@
  *     US Joint Forces Command Joint Concept Development & Experimentation (J9)
  *     http://www.jfcom.mil/about/abt_j9.htm
  *
- * $Revision: 19929 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-04-07 06:21:40 +0200 (lun 07 avr 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_TRANSPORT_H
-#define __OPAL_TRANSPORT_H
+#ifndef OPAL_OPAL_TRANSPORT_H
+#define OPAL_OPAL_TRANSPORT_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -363,23 +363,6 @@ class OpalListener : public PObject
 PLIST(OpalListenerList, OpalListener);
 
 
-/** Return a list of transport addresses corresponding to a listener list
-  */
-OpalTransportAddressArray OpalGetInterfaceAddresses(
-  const OpalListenerList & listeners, ///<  List of listeners
-  PBoolean excludeLocalHost = PTrue,       ///<  Flag to exclude 127.0.0.1
-  OpalTransport * associatedTransport = NULL
-                          ///<  Associated transport for precedence and translation
-);
-
-OpalTransportAddressArray OpalGetInterfaceAddresses(
-  const OpalTransportAddress & addr,  ///<  Possible INADDR_ANY address
-  PBoolean excludeLocalHost = PTrue,       ///<  Flag to exclude 127.0.0.1
-  OpalTransport * associatedTransport = NULL
-                          ///<  Associated transport for precedence and translation
-);
-
-
 class OpalListenerIP : public OpalListener
 {
   PCLASSINFO(OpalListenerIP, OpalListener);
@@ -785,9 +768,12 @@ class OpalTransport : public PIndirectChannel
       */
     virtual const char * GetProtoPrefix() const = 0;
 
+    PMutex & GetWriteMutex() { return m_writeMutex; }
+
   protected:
     OpalEndPoint & endpoint;
     PThread      * thread;      ///<  Thread handling the transport
+    PMutex         m_writeMutex;
 };
 
 
@@ -939,7 +925,8 @@ class OpalTransportUDP : public OpalTransportIP
       OpalEndPoint & endpoint,    ///<  Endpoint object
       PIPSocket::Address binding = PIPSocket::GetDefaultIpAny(), ///<  Local interface to use
       WORD port = 0,              ///<  Local port to bind to
-      PBoolean reuseAddr = PFalse      ///<  Flag for binding to already bound interface
+      bool reuseAddr = false,     ///<  Flag for binding to already bound interface
+      bool preOpen = false        ///<  Flag to pre-open socket
     );
 
     /**Create a new transport channel.
@@ -1180,7 +1167,7 @@ class OpalInternalIPTransportTemplate : public OpalInternalIPTransport
 typedef OpalInternalIPTransportTemplate<OpalListenerTCP, OpalTransportTCP, OpalTransportAddress::Datagram, OpalTransportUDP> OpalInternalTCPTransport;
 typedef OpalInternalIPTransportTemplate<OpalListenerUDP, OpalTransportUDP, OpalTransportAddress::Streamed, OpalTransportTCP> OpalInternalUDPTransport;
 
-#if P_SSL
+#if OPAL_PTLIB_SSL
 
 class PSSLContext;
 
@@ -1243,10 +1230,10 @@ class OpalTransportTCPS : public OpalTransportTCP
 typedef OpalInternalIPTransportTemplate<OpalListenerTCPS, OpalTransportTCPS, OpalTransportAddress::Datagram, OpalTransportUDP> OpalInternalTCPSTransport;
 
 
-#endif // P_SSL
+#endif // OPAL_PTLIB_SSL
 
 
-#endif  // __OPAL_TRANSPORT_H
+#endif  // OPAL_OPAL_TRANSPORT_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
