@@ -23,13 +23,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20790 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-08-31 08:15:19 +0200 (dim 31 aoû 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_HANDLERS_H
-#define __OPAL_HANDLERS_H
+#ifndef OPAL_SIP_HANDLERS_H
+#define OPAL_SIP_HANDLERS_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -39,8 +39,13 @@
 #include <ptlib.h>
 #endif
 
+#include <opal/buildopts.h>
+
+#if OPAL_SIP
+
 #include <ptlib/safecoll.h>
 
+#include <opal/connection.h>
 #include <sip/sippdu.h>
 
 
@@ -70,6 +75,7 @@ public:
 
     Subscribed,       // The registration is active
     Subscribing,      // The registration is in process
+    Unavailable,      // The registration is offline and still being attempted
     Refreshing,       // The registration is being refreshed
     Restoring,        // The registration is trying to be restored after being offline
     Unsubscribing,    // The unregistration is in process
@@ -101,8 +107,6 @@ public:
   virtual PString GetCallID()
     { return callID; }
 
-  virtual PBoolean CanBeDeleted();
-
   virtual void SetBody(const PString & b)
     { body = b;}
 
@@ -121,6 +125,8 @@ public:
 
   const PStringList & GetRouteSet() const { return routeSet; }
 
+  const OpalProductInfo & GetProductInfo() const { return m_productInfo; }
+
   PString                     authenticationUsername;
   PString                     authenticationPassword;
   PString                     authenticationAuthRealm;
@@ -151,6 +157,7 @@ protected:
   PTimeInterval               retryTimeoutMax; 
   PString remotePartyAddress;
   SIPURL proxy;
+  OpalProductInfo             m_productInfo;
 };
 
 #if PTRACING
@@ -184,6 +191,7 @@ private:
   void SendStatus(SIP_PDU::StatusCodes code);
 
   SIPRegister::Params m_parameters;
+  unsigned            m_sequenceNumber;
 };
 
 
@@ -197,6 +205,8 @@ public:
   virtual SIPTransaction * CreateTransaction (OpalTransport &);
   virtual void OnReceivedOK(SIPTransaction & transaction, SIP_PDU & response);
   virtual PBoolean OnReceivedNOTIFY(SIP_PDU & response);
+  virtual void OnFailed(SIP_PDU::StatusCodes r);
+  virtual PBoolean SendRequest(SIPHandler::State state);
   virtual SIP_PDU::Methods GetMethod ()
     { return SIP_PDU::Method_SUBSCRIBE; }
   virtual PCaselessString GetEventPackage() const
@@ -205,6 +215,7 @@ public:
   void UpdateParameters(const SIPSubscribe::Params & params);
 
 private:
+  void SendStatus(SIP_PDU::StatusCodes code);
   PBoolean OnReceivedMWINOTIFY(SIP_PDU & response);
   PBoolean OnReceivedPresenceNOTIFY(SIP_PDU & response);
 
@@ -283,11 +294,11 @@ public:
  */
 class SIPHandlersList : public PSafeList<SIPHandler>
 {
-public:
+  public:
     /**
      * Return the number of registered accounts
      */
-    unsigned GetRegistrationsCount();
+    unsigned GetCount(SIP_PDU::Methods meth, const PString & eventPackage = PString::Empty()) const;
 
     /**
      * Find the SIPHandler object with the specified callID
@@ -318,4 +329,6 @@ public:
 };
 
 
-#endif
+#endif // OPAL_SIP
+
+#endif // OPAL_SIP_HANDLERS_H
