@@ -24,13 +24,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_SDP_H
-#define __OPAL_SDP_H
+#ifndef OPAL_SIP_SDP_H
+#define OPAL_SIP_SDP_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -38,6 +38,8 @@
 
 #include <opal/buildopts.h>
 
+#if OPAL_SIP
+
 #include <opal/transports.h>
 #include <opal/mediatype.h>
 #include <opal/mediafmt.h>
@@ -359,7 +361,9 @@ class SDPSessionDescription : public PObject
 /////////////////////////////////////////////////////////
 
 
-#endif // __OPAL_SDP_H
+#endif // OPAL_SIP
+
+#endif // OPAL_SIP_SDP_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
