@@ -24,19 +24,25 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 19279 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-01-17 05:08:34 +0100 (jeu 17 jan 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_SIP_H
-#define __OPAL_SIP_H
+#ifndef OPAL_SIP_SIP_H
+#define OPAL_SIP_SIP_H
+
+#include <opal/buildopts.h>
+
+#if OPAL_SIP
 
 #include <sip/sipep.h>
 #include <sip/sipcon.h>
 
 
-#endif // __OPAL_SIP_H
+#endif // OPAL_SIP
+
+#endif // OPAL_SIP_SIP_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
