@@ -24,13 +24,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
-#ifndef __OPAL_SIPCON_H
-#define __OPAL_SIPCON_H
+#ifndef OPAL_SIP_SIPCON_H
+#define OPAL_SIP_SIPCON_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -38,6 +38,8 @@
 
 #include <opal/buildopts.h>
 
+#if OPAL_SIP
+
 #include <opal/buildopts.h>
 #include <opal/rtpconn.h>
 #include <sip/sippdu.h>
@@ -560,7 +562,9 @@ class SIP_RTP_Session : public RTP_UserData
 };
 
 
-#endif // __OPAL_SIPCON_H
+#endif // OPAL_SIP
+
+#endif // OPAL_SIP_SIPCON_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
