@@ -24,13 +24,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21062 $
- * $Author: rjongbloed $
- * $Date: 2008-09-18 11:41:40 +0000 (Thu, 18 Sep 2008) $
+ * $Revision: 21288 $
+ * $Author: dsandras $
+ * $Date: 2008-10-12 14:50:25 +0000 (Sun, 12 Oct 2008) $
  */
 
-#ifndef __OPAL_SIPEP_H
-#define __OPAL_SIPEP_H
+#ifndef OPAL_SIP_SIPEP_H
+#define OPAL_SIP_SIPEP_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -42,6 +42,8 @@
 
 #include <opal/buildopts.h>
 
+#if OPAL_SIP
+
 #include <ptclib/sockagg.h>
 #include <opal/rtpep.h>
 #include <sip/sipcon.h>
@@ -742,24 +744,33 @@ class SIPEndPoint : public OpalRTPEndPoint
     typedef PThreadPool<SIP_PDU_Work, SIP_PDU_Thread> SIPMainThreadPool;
     SIPMainThreadPool threadPool;
 
+    enum {
+      HighPriority = 80,
+      LowPriority  = 30,
+    };
     class InterfaceMonitor : public PInterfaceMonitorClient
     {
         PCLASSINFO(InterfaceMonitor, PInterfaceMonitorClient);
       public:
-        InterfaceMonitor(SIPEndPoint & manager);
+        InterfaceMonitor(SIPEndPoint & manager, PINDEX priority);
         
         virtual void OnAddInterface(const PIPSocket::InterfaceEntry & entry);
         virtual void OnRemoveInterface(const PIPSocket::InterfaceEntry & entry);
 
     protected:
         SIPEndPoint & m_endpoint;
-    } m_interfaceMonitor;
+    };
+    InterfaceMonitor m_highPriorityMonitor;
+    InterfaceMonitor m_lowPriorityMonitor;
 
     friend void InterfaceMonitor::OnAddInterface(const PIPSocket::InterfaceEntry & entry);
     friend void InterfaceMonitor::OnRemoveInterface(const PIPSocket::InterfaceEntry & entry);
 };
 
-#endif // __OPAL_SIPEP_H
+
+#endif // OPAL_SIP
+
+#endif // OPAL_SIP_SIPEP_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
