@@ -25,9 +25,9 @@
  * Contributor(s): Michele Piccini (michele@piccini.com)
  *                 Derek Smithies (derek@indranet.co.nz)
  *
- * $Revision: 20629 $
- * $Author: rjongbloed $
- * $Date: 2008-07-28 09:57:33 +0200 (lun 28 jui 2008) $
+ * $Revision: 20951 $
+ * $Author: ms30002000 $
+ * $Date: 2008-09-14 10:10:29 +0000 (Sun, 14 Sep 2008) $
  */
 
 /*
@@ -55,6 +55,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <algorithm>
 
 #ifndef PLUGIN_CODEC_DLL_EXPORTS
 #include "plugin-config.h"
@@ -380,7 +381,6 @@ static int encoder_set_options(const PluginCodec_Definition *,
         bitrate = atoi(options[i+1]);
       if (STRCMPI(options[i], PLUGINCODEC_OPTION_TEMPORAL_SPATIAL_TRADE_OFF) == 0)
         tsto = atoi(options[i+1]);
-      printf ("%s = %s \n", options[i], options[i+1]);
     }
   }
   context->SetFrameSize (width, height);
