@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20924 $
+ * $Revision: 21326 $
  * $Author: rjongbloed $
- * $Date: 2008-09-11 03:50:36 +0000 (Thu, 11 Sep 2008) $
+ * $Date: 2008-10-14 07:22:43 +0000 (Tue, 14 Oct 2008) $
  */
 
 #include "stdafx.h"
@@ -453,6 +453,9 @@ void CMobileOpalDlg::InitialiseOPAL()
 
   CStringA strStunServer = GetOptionStringA(STUNServerKey);
   command.m_param.m_general.m_stunServer = strStunServer;
+  command.m_param.m_general.m_audioPlayerDevice = "Audio Output";
+  command.m_param.m_general.m_audioRecordDevice = "Audio Input";
+  command.m_param.m_general.m_mediaMask = "RFC4175*";
 
   if ((response = OpalSendMessage(m_opal, &command)) == NULL || response->m_type == OpalIndCommandError)
     ErrorBox(IDS_CONFIGURATION_FAIL, response);
