@@ -23,13 +23,14 @@
 *
 * Contributor(s): ______________________________________.
 *
-* $Revision: 20383 $
+* $Revision: 21004 $
 * $Author: rjongbloed $
-* $Date: 2008-06-04 12:09:41 +0200 (mer 04 jun 2008) $
+* $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
 */
 
 
 #include <ptlib.h>
+#include <opal/buildopts.h>
 #include <codec/g711a1_plc.h>
 
 #if OPAL_G711PLC
@@ -57,7 +58,7 @@ static const double PITCH_LOW=66.6;/**< minimum allowed pitch. default 66 Hz [Hz
 static const double PITCH_HIGH=200;/**< maximum allowed pitch. default 200 Hz [Hz] */
 
 
-#ifdef _WIN32
+#ifdef _MSC_VER
 __inline double round(const double & value)
 {
   return value < 0 ? floor(value-0.5) : ceil(value+0.5);
