@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21115 $
+ * $Revision: 21159 $
  * $Author: rjongbloed $
- * $Date: 2008-09-22 03:00:58 +0000 (Mon, 22 Sep 2008) $
+ * $Date: 2008-09-25 03:12:55 +0000 (Thu, 25 Sep 2008) $
  */
 
 #include <ptlib.h>
@@ -1469,14 +1469,14 @@ static void AddInfoRequestResponseCall(H225_InfoRequestResponse & irr,
   info.IncludeOptionalField(H225_InfoRequestResponse_perCallInfo_subtype::e_originator);
   info.m_originator = !connection.HadAnsweredCall();
 
-  H323_RTP_Session * session = connection.GetSessionCallbacks(OpalMediaFormat::DefaultAudioSessionID);
+  H323_RTP_Session * session = connection.GetSessionCallbacks(H323Capability::DefaultAudioSessionID);
   if (session != NULL) {
     info.IncludeOptionalField(H225_InfoRequestResponse_perCallInfo_subtype::e_audio);
     info.m_audio.SetSize(1);
     session->OnSendRasInfo(info.m_audio[0]);
   }
 
-  session = connection.GetSessionCallbacks(OpalMediaFormat::DefaultVideoSessionID);
+  session = connection.GetSessionCallbacks(H323Capability::DefaultVideoSessionID);
   if (session != NULL) {
     info.IncludeOptionalField(H225_InfoRequestResponse_perCallInfo_subtype::e_video);
     info.m_video.SetSize(1);
