@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 19626 $
+ * $Revision: 21231 $
  * $Author: rjongbloed $
- * $Date: 2008-02-29 03:49:32 +0000 (Fri, 29 Feb 2008) $
+ * $Date: 2008-10-03 11:48:42 +0000 (Fri, 03 Oct 2008) $
  */
 
 #include <ptlib.h>
@@ -704,8 +704,12 @@ PBoolean H245NegLogicalChannel::HandleOpenAck(const H245_OpenLogicalChannelAck &
       state = e_Established;
       replyTimer.Stop();
 
-      if (!channel->OnReceivedAckPDU(pdu))
-        return CloseWhileLocked();
+      if (!channel->OnReceivedAckPDU(pdu)) {
+        if (connection.GetRemoteProductInfo().name != "Cisco IOS")
+          return CloseWhileLocked();
+        PTRACE(4, "H245\tWorkaround for Cisco bug, cannot close channel on illegal ack or it hangs up on you.");
+        return true;
+      }
 
       if (channel->GetDirection() == H323Channel::IsBidirectional) {
         H323ControlPDU reply;
