@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21115 $
+ * $Revision: 21186 $
  * $Author: rjongbloed $
- * $Date: 2008-09-22 03:00:58 +0000 (Mon, 22 Sep 2008) $
+ * $Date: 2008-09-29 06:25:12 +0000 (Mon, 29 Sep 2008) $
  */
 
 #include <ptlib.h>
@@ -232,18 +232,16 @@ PBoolean H323Transactor::SetTransport(const H323TransportAddress & iface)
   return StartChannel();;
 }
 
-H323TransportAddressArray H323Transactor::GetInterfaceAddresses(PBoolean excludeLocalHost,
-                                                                H323Transport * associatedTransport)
+
+H323TransportAddressArray H323Transactor::GetInterfaceAddresses(bool excludeLocalHost)
 {
   if (transport == NULL)
     return H323TransportAddressArray();
   else
-    return OpalGetInterfaceAddresses(transport->GetLocalAddress(),
-                                     excludeLocalHost,
-                                     associatedTransport,
-                                     NULL);
+    return endpoint.GetInterfaceAddresses(excludeLocalHost, transport);
 }
 
+
 PBoolean H323Transactor::StartChannel()
 {
   if (transport == NULL)
