@@ -25,17 +25,15 @@
  *
  * The author of this code is Derek J Smithies
  *
- *
- *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
 #include <ptlib.h>
 #include <opal/buildopts.h>
-#include <typeinfo>
 
+#if OPAL_IAX2
 
 #ifdef P_USE_PRAGMA
 #pragma implementation "iax2con.h"
@@ -50,6 +48,8 @@
 #include <iax2/sound.h>
 #include <iax2/transmit.h>
 
+#include <typeinfo>
+
 
 #define new PNEW
 
@@ -536,6 +536,9 @@ PBoolean IAX2Connection::ReadSoundPacket(RTP_DataFrame & packet)
   return PTrue;
 }
 
+
+#endif // OPAL_IAX2
+
 /* The comment below is magic for those who use emacs to edit this file. */
 /* With the comment below, the tab key does auto indent to 2 spaces.     */
 
