@@ -24,21 +24,20 @@
  *
  * The author of this code is Derek J Smithies
  *
- *
- *
- * $Revision: 21004 $
+ * $Revision: 21283 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-11 07:10:58 +0000 (Sat, 11 Oct 2008) $
  */
 
 #include <ptlib.h>
 #include <opal/buildopts.h>
 
+#if OPAL_IAX2
+
 #ifdef P_USE_PRAGMA
 #pragma implementation "iax2jitter.h"
 #endif
 
-
 #include <iax2/iax2jitter.h>
 #include <rtp/rtp.h>
 
@@ -128,6 +127,9 @@ PBoolean IAX2JitterBuffer::OnReadPacket(RTP_DataFrame & frame,
     return PTrue;
 }
 
+
+#endif // OPAL_IAX2
+
 ////////////////////////////////////////////////////////////////////////////////
 /* The comment below is magic for those who use emacs to edit this file. */
 /* With the comment below, the tab key does auto indent to 4 spaces.     */
