@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20619 $
+ * $Revision: 21367 $
  * $Author: rjongbloed $
- * $Date: 2008-07-25 11:28:27 +0200 (ven 25 jui 2008) $
+ * $Date: 2008-10-16 09:40:48 +0000 (Thu, 16 Oct 2008) $
  */
 
 #include <ptlib.h>
@@ -34,6 +34,8 @@
 #pragma implementation "lid.cxx"
 #endif
 
+#include <opal/buildopts.h>
+
 #include <lids/lid.h>
 
 
@@ -49,14 +51,13 @@ static OpalLIDRegistration * RegisteredLIDsListHead;
 ostream & operator<<(ostream & o, OpalLineInterfaceDevice::CallProgressTones t)
 {
   static const char * const CallProgressTonesNames[OpalLineInterfaceDevice::NumTones+1] = {
-    "NoTone", "DialTone", "RingTone", "BusyTone", "CongestionTone", "ClearTone", "MwiTone", "CNGTone", "CEDTone"
+    "NoTone", "DialTone", "RingTone", "BusyTone", "CongestionTone", "ClearTone", "MwiTone", "RoutingTone", "CNGTone", "CEDTone", "UserTone"
   };
-  if (t+1 < PARRAYSIZE(CallProgressTonesNames))
+  if (t+1 < PARRAYSIZE(CallProgressTonesNames) && CallProgressTonesNames[t+1] != NULL)
     return o << CallProgressTonesNames[t+1];
   else
-    return o << "Unknown";
+    return o << "UnknownTone:" << (unsigned)t;
 }
-
 #endif
 
 
@@ -74,6 +75,7 @@ OpalLineInterfaceDevice::OpalLineInterfaceDevice()
   m_callProgressTones[CongestionTone] = "480+620:0.3-0.2";
   m_callProgressTones[ClearTone] = "350+440:0.5";
   m_callProgressTones[MwiTone] = "350+440:0.2";
+  m_callProgressTones[RoutingTone] = "1760:0.1-0.1-0.1-4.7";
   m_callProgressTones[CNGTone] = "1100:0.5";
   m_callProgressTones[CEDTone] = "2100:0.5";
 }
@@ -1090,30 +1092,39 @@ void OpalLine::PrintOn(ostream & strm) const
 }
 
 
-unsigned OpalLine::GetRingCount(DWORD * cadence)
+PBoolean OpalLine::IsRinging(DWORD * cadence)
 {
   PTimeInterval tick = PTimer::Tick();
-
   PTimeInterval delta = tick - ringTick;
-  if (delta > ringStoppedTime) {
+  if (ringCount > 0 && delta > ringStoppedTime) {
     PTRACE(4, "LID\tRing count reset on line " << lineNumber);
+    lastRingState = false;
     ringCount = 0;
   }
 
-  if (IsRinging(cadence)) {
-    lastRingState = true;
+  if (device.IsLineRinging(lineNumber, cadence)) {
     ringTick = tick;
-    if (ringCount == 0) {
-      PTRACE(4, "LID\tRing start detected on line " << lineNumber);
-      ringCount = 1;
-    }
-  }
-  else if (lastRingState && delta > ringInterCadenceTime) {
-    PTRACE(4, "LID\tRing cadence incremented on line " << lineNumber);
+    if (lastRingState)
+      return true;
+
+    PTRACE_IF(4, ringCount == 0, "LID\tRing start detected on line " << lineNumber);
     ringCount++;
+    lastRingState = true;
+    return true;
+  }
+
+  if (lastRingState && delta > ringInterCadenceTime) {
+    PTRACE(4, "LID\tRing cadence incremented on line " << lineNumber);
     lastRingState = false;
   }
 
+  return lastRingState;
+}
+
+
+unsigned OpalLine::GetRingCount(DWORD * cadence)
+{
+  IsRinging(cadence);
   return ringCount;
 }
 
