@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21163 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-09-25 06:36:06 +0000 (Thu, 25 Sep 2008) $
  */
 
 #include <ptlib.h>
@@ -181,7 +181,7 @@ PBoolean OpalCall::OnAlerting(OpalConnection & connection)
   if (isClearing)
     return false;
 
-  PBoolean hasMedia = connection.GetMediaStream(OpalMediaFormat::DefaultAudioSessionID, PTrue) != NULL;
+  PBoolean hasMedia = connection.GetMediaStream(OpalMediaType::Audio(), true) != NULL;
 
   bool ok = false;
 
@@ -420,18 +420,14 @@ PBoolean OpalCall::OpenSourceMediaStreams(OpalConnection & connection,
     if (sourceFormat.IsValid())
       sourceMediaFormats = sourceFormat; // Use the source format already established
     else {
-      sourceMediaFormats = connection.GetMediaFormats();
-
-      if (preselectedFormat.IsValid()  && sourceMediaFormats.HasFormat(preselectedFormat))
+      OpalMediaFormatList connectionMediaFormats = connection.GetMediaFormats();
+      if (preselectedFormat.IsValid()  && connectionMediaFormats.HasFormat(preselectedFormat))
         sourceMediaFormats = preselectedFormat;
       else {
-        // remove any media formats that do not match the media type
-        PINDEX i = 0;
-        while (i < sourceMediaFormats.GetSize()) {
-          if (sourceMediaFormats[i].GetMediaType() != mediaType)
-            sourceMediaFormats.RemoveAt(i);
-          else
-            i++;
+        // Only include media formats that are of the same media type
+        for (OpalMediaFormatList::iterator i = connectionMediaFormats.begin(); i != connectionMediaFormats.end(); ++i) {
+          if (i->GetMediaType() == mediaType)
+            sourceMediaFormats += *i;
         }
       }
     }
