@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21163 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-09-25 06:36:06 +0000 (Thu, 25 Sep 2008) $
  */
 
 #include <ptlib.h>
@@ -174,18 +174,18 @@ OpalIVRConnection::~OpalIVRConnection()
 }
 
 
+PString OpalIVRConnection::GetLocalPartyURL() const
+{
+  return GetPrefixName() + ':' + vxmlToLoad.Left(vxmlToLoad.FindOneOf("\r\n"));
+}
+
+
 PBoolean OpalIVRConnection::SetUpConnection()
 {
-  originating = true;
+  originating = false;
 
   ApplyStringOptions();
 
-  PSafePtr<OpalConnection> otherConnection = GetOtherPartyConnection();
-  if (otherConnection != NULL)
-    remotePartyName = otherConnection->GetRemotePartyName();
-  else
-    remotePartyName = ownerCall.GetPartyB();
-
   PTRACE(3, "IVR\tSetUpConnection(" << remotePartyName << ')');
 
   SetPhase(AlertingPhase);
@@ -380,10 +380,11 @@ PBoolean OpalIVRConnection::SendUserInputString(const PString & value)
   return PTrue;
 }
 
-void OpalIVRConnection::OnMediaPatchStop(unsigned sessionId, bool isSource)
+void OpalIVRConnection::OnMediaPatchStop(unsigned sessionId, bool)
 {
-  // lose the audio patch, then lose the call
-  if (isSource && sessionId == OpalMediaFormat::DefaultAudioSessionID)
+  // lose the audio, then lose the call
+  OpalMediaStreamPtr stream = GetMediaStream(OpalMediaType::Audio(), true);
+  if (stream == NULL || !stream->IsOpen() || stream->GetSessionID() == sessionId)
     Release();
 }
 
