@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20767 $
- * $Author: rjongbloed $
- * $Date: 2008-08-29 08:44:24 +0200 (ven 29 aoû 2008) $
+ * $Revision: 21352 $
+ * $Author: csoutheren $
+ * $Date: 2008-10-16 00:31:22 +0000 (Thu, 16 Oct 2008) $
  */
 
 #include <ptlib.h>
@@ -35,8 +35,9 @@
 #pragma implementation "manager.h"
 #endif
 
-#include <opal/manager.h>
+#include <opal/buildopts.h>
 
+#include <opal/manager.h>
 #include <opal/endpoint.h>
 #include <opal/call.h>
 #include <opal/patch.h>
@@ -55,11 +56,13 @@
 
 
 static const char * const DefaultMediaFormatOrder[] = {
+  OPAL_GSMAMR,
   OPAL_G7231_6k3,
   OPAL_G729B,
   OPAL_G729AB,
   OPAL_G729,
   OPAL_G729A,
+  OPAL_iLBC,
   OPAL_GSM0610,
   OPAL_G728,
   OPAL_G711_ULAW_64K,
@@ -105,6 +108,11 @@ OpalProductInfo::OpalProductInfo()
   , t35Extension(0)       // No extension code for Australia
   , manufacturerCode(61)  // Allocated by Australian Communications Authority, Oct 2000;
 {
+  // Sanitise the product name to be compatible with SIP User-Agent rules
+  name.Replace(' ', '-', true);
+  PINDEX pos;
+  while ((pos = name.FindSpan("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-.!%*_+`'~")) != P_MAX_INDEX)
+    name.Delete(pos, 1);
 }
 
 OpalProductInfo & OpalProductInfo::Default()
@@ -161,7 +169,7 @@ OpalManager::OpalManager()
   tcpPorts.current = tcpPorts.base = tcpPorts.max = 0;
   udpPorts.current = udpPorts.base = udpPorts.max = 0;
 
-#ifndef NO_OPAL_VIDEO
+#if OPAL_PTLIB_VIDEO
   PStringArray devices = PVideoInputDevice::GetDriversDeviceNames("*"); // Get all devices on all drivers
   PINDEX i;
   for (i = 0; i < devices.GetSize(); ++i) {
@@ -716,7 +724,10 @@ PBoolean OpalManager::CreateVideoOutputDevice(const OpalConnection & connection,
                                           PBoolean & autoDelete)
 {
   // Donot use our one and only SDL window, if we need it for the video output.
-  if (preview && videoPreviewDevice.driverName == "SDL" && videoOutputDevice.driverName == "SDL")
+  if (preview && (
+      (videoPreviewDevice.driverName == "SDL" && videoOutputDevice.driverName == "SDL") ||
+      (videoPreviewDevice.deviceName == "SDL" && videoOutputDevice.deviceName == "SDL")
+      ))
     return PFalse;
 
   // Make copy so we can adjust the size
@@ -1229,7 +1240,7 @@ void OpalManager::SetTranslationAddress(const PIPSocket::Address & address)
 }
 
 
-PSTUNClient * OpalManager::GetSTUN(const PIPSocket::Address & ip) const
+PNatMethod * OpalManager::GetNatMethod(const PIPSocket::Address & ip) const
 {
   if (ip.IsValid() && IsLocalAddress(ip))
     return NULL;
@@ -1257,8 +1268,8 @@ PSTUNClient::NatTypes OpalManager::SetSTUNServer(const PString & server)
     stun->SetServer(server);
   else {
     stun = new PSTUNClient(server,
-                           GetUDPPortBase(), GetUDPPortMax(),
-                           GetRtpIpPortBase(), GetRtpIpPortMax());
+                                         GetUDPPortBase(), GetUDPPortMax(),
+                                         GetRtpIpPortBase(), GetRtpIpPortMax());
     interfaceMonitor = new InterfaceMonitor(*this);
   }
 
@@ -1538,7 +1549,7 @@ void OpalManager::InterfaceMonitor::OnAddInterface(const PIPSocket::InterfaceEnt
 
 void OpalManager::InterfaceMonitor::OnRemoveInterface(const PIPSocket::InterfaceEntry & entry)
 {
-  PSTUNClient * stun = m_manager.GetSTUN();
+  PSTUNClient * stun = m_manager.GetSTUNClient();
   PIPSocket::Address addr;
   if (stun != NULL && stun->GetInterfaceAddress(addr) && entry.GetAddress() == addr)
     stun->InvalidateCache();
