@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
+ * $Revision: 21159 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-09-25 03:12:55 +0000 (Thu, 25 Sep 2008) $
  */
 
 #include <ptlib.h>
@@ -742,9 +742,9 @@ void OpalManager_C::PostMessage(OpalMessageBuffer & message)
   m_messageMutex.Wait();
   if (m_messageAvailableCallback == NULL || m_messageAvailableCallback(message)) {
     m_messageQueue.push(message.Detach());
-    m_messageMutex.Signal();
+    m_messagesAvailable.Signal();
   }
-  m_messagesAvailable.Signal();
+  m_messageMutex.Signal();
 }
 
 
@@ -1514,19 +1514,8 @@ void OpalManager_C::OnIndMediaStream(const OpalMediaStream & stream, OpalMediaSt
   OpalMessageBuffer message(OpalIndMediaStream);
   SET_MESSAGE_STRING(message, m_param.m_mediaStream.m_callToken, connection.GetCall().GetToken());
   SET_MESSAGE_STRING(message, m_param.m_mediaStream.m_identifier, stream.GetID());
-  PString type;
-  switch (stream.GetMediaFormat().GetDefaultSessionID()) {
-    case OpalMediaFormat::DefaultAudioSessionID :
-      type = "audio";
-      break;
-    case OpalMediaFormat::DefaultVideoSessionID :
-      type = "video";
-      break;
-    case OpalMediaFormat::DefaultDataSessionID :
-      type = "fax";
-      break;
-  }
-  type += stream.IsSource() ? " in" : " out";
+  PStringStream type;
+  type << stream.GetMediaFormat().GetMediaType() << (stream.IsSource() ? " in" : " out");
   SET_MESSAGE_STRING(message, m_param.m_mediaStream.m_type, type);
   SET_MESSAGE_STRING(message, m_param.m_mediaStream.m_format, stream.GetMediaFormat().GetName());
   message->m_param.m_mediaStream.m_state = state;
