@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20421 $
- * $Author: ykiryanov $
- * $Date: 2008-06-08 03:01:08 +0200 (dim 08 jun 2008) $
+ * $Revision: 21004 $
+ * $Author: rjongbloed $
+ * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
  */
 
 #ifdef P_USE_PRAGMA
@@ -34,6 +34,8 @@
 
 #include <ptlib.h>
 
+#include <opal/buildopts.h>
+
 #include <opal/opalvxml.h>
 
 #include <opal/connection.h>
@@ -42,7 +44,7 @@
 
 ///////////////////////////////////////////////////////////////
 
-#if defined(P_EXPAT) && defined(P_VXML)
+#if OPAL_PTLIB_VXML
 
 OpalVXMLSession::OpalVXMLSession(OpalConnection * _conn, PTextToSpeech * tts, PBoolean autoDelete)
   : PVXMLSession(tts, autoDelete),
@@ -86,7 +88,7 @@ PWAVFile * OpalVXMLSession::CreateWAVFile(const PFilePath & fn, PFile::OpenMode
 }
 
 
-#endif // P_EXPAT
+#endif // #if OPAL_PTLIB_EXPAT
 
 
 // End of File /////////////////////////////////////////////////////////////
