@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20798 $
- * $Author: csoutheren $
- * $Date: 2008-08-31 15:09:49 +0200 (dim 31 aoû 2008) $
+ * $Revision: 21159 $
+ * $Author: rjongbloed $
+ * $Date: 2008-09-25 03:12:55 +0000 (Thu, 25 Sep 2008) $
  */
 
 #include <ptlib.h>
@@ -35,9 +35,10 @@
 #endif
 
 #include <opal/buildopts.h>
+
 #include <opal/pcss.h>
 
-#if P_AUDIO
+#if OPAL_PTLIB_AUDIO
 
 #if OPAL_VIDEO
 #include <ptlib/videoio.h>
@@ -365,7 +366,7 @@ OpalMediaStreamPtr OpalPCSSConnection::OpenMediaStream(const OpalMediaFormat & m
 {
 #if OPAL_VIDEO
   if ( isSource &&
-       sessionID == OpalMediaFormat::DefaultVideoSessionID &&
+       mediaFormat.GetMediaType() == OpalMediaType::Video() &&
       !ownerCall.IsEstablished() &&
       !endpoint.GetManager().CanAutoStartTransmitVideo()) {
     PTRACE(3, "PCSS\tOpenMediaStream auto start disabled, refusing video open");
@@ -379,7 +380,7 @@ OpalMediaStreamPtr OpalPCSSConnection::OpenMediaStream(const OpalMediaFormat & m
 
 PBoolean OpalPCSSConnection::SetAudioVolume(PBoolean source, unsigned percentage)
 {
-  PSafePtr<OpalAudioMediaStream> stream = PSafePtrCast<OpalMediaStream, OpalAudioMediaStream>(GetMediaStream(OpalMediaFormat::DefaultAudioSessionID, source));
+  PSafePtr<OpalAudioMediaStream> stream = PSafePtrCast<OpalMediaStream, OpalAudioMediaStream>(GetMediaStream(OpalMediaType::Audio(), source));
   if (stream == NULL)
     return PFalse;
 
@@ -393,7 +394,7 @@ PBoolean OpalPCSSConnection::SetAudioVolume(PBoolean source, unsigned percentage
 
 unsigned OpalPCSSConnection::GetAudioSignalLevel(PBoolean source)
 {
-  PSafePtr<OpalAudioMediaStream> stream = PSafePtrCast<OpalMediaStream, OpalAudioMediaStream>(GetMediaStream(OpalMediaFormat::DefaultAudioSessionID, source));
+  PSafePtr<OpalAudioMediaStream> stream = PSafePtrCast<OpalMediaStream, OpalAudioMediaStream>(GetMediaStream(OpalMediaType::Audio(), source));
   if (stream == NULL)
     return UINT_MAX;
 
@@ -422,7 +423,7 @@ void OpalPCSSConnection::AcceptIncoming()
   }
 }
 
-#endif // P_AUDIO
+#endif // OPAL_PTLIB_AUDIO
 
 
 /////////////////////////////////////////////////////////////////////////////
