@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21029 $
+ * $Revision: 21359 $
  * $Author: rjongbloed $
- * $Date: 2008-09-16 23:58:39 +0000 (Tue, 16 Sep 2008) $
+ * $Date: 2008-10-16 04:29:02 +0000 (Thu, 16 Oct 2008) $
  */
 
 #include <ptlib.h>
@@ -656,7 +656,7 @@ bool SIPConnection::OfferSDPMediaDescription(const OpalMediaType & mediaType,
     localMedia->AddMediaFormats(formats, mediaType);
 
 #if OPAL_VIDEO
-    if (rtpSessionId == OpalMediaFormat::DefaultVideoSessionID) {
+    if (mediaType == OpalMediaType::Video()) {
       if (endpoint.GetManager().CanAutoStartTransmitVideo())
         localMedia->SetDirection(endpoint.GetManager().CanAutoStartReceiveVideo() ? SDPMediaDescription::SendRecv : SDPMediaDescription::SendOnly);
       else
@@ -787,7 +787,7 @@ PBoolean SIPConnection::AnswerSDPMediaDescription(const SDPSessionDescription &
 
   SDPMediaDescription::Direction otherSidesDir = sdpIn.GetDirection(rtpSessionId);
 #if OPAL_VIDEO
-  if (rtpSessionId == OpalMediaFormat::DefaultVideoSessionID && GetPhase() < EstablishedPhase) {
+  if (mediaType == OpalMediaType::Video() && GetPhase() < EstablishedPhase) {
     // If processing initial INVITE and video, obey the auto-start flags
     if (!endpoint.GetManager().CanAutoStartTransmitVideo())
       otherSidesDir = (otherSidesDir&SDPMediaDescription::SendOnly) != 0 ? SDPMediaDescription::SendOnly : SDPMediaDescription::Inactive;
@@ -864,7 +864,7 @@ PBoolean SIPConnection::AnswerSDPMediaDescription(const SDPSessionDescription &
     for (OpalMediaFormatList::iterator remoteFormat = remoteFormatList.begin(); remoteFormat != remoteFormatList.end(); ++remoteFormat) {
       for (OpalMediaFormatList::iterator localFormat = localFormatList.begin(); localFormat != localFormatList.end(); ++localFormat) {
         OpalMediaFormat intermediateFormat;
-        if (remoteFormat->GetDefaultSessionID() == rtpSessionId &&
+        if (remoteFormat->GetMediaType() == mediaType &&
             OpalTranscoder::FindIntermediateFormat(*localFormat, *remoteFormat, intermediateFormat)) {
           localMedia->AddMediaFormat(*remoteFormat);
           empty = false;
@@ -1056,6 +1056,8 @@ PBoolean SIPConnection::SetUpConnection()
     return PFalse;
   }
 
+  PWaitAndSignal mutex(transport->GetWriteMutex());
+
   if (!transport->WriteConnect(WriteINVITE, this)) {
     PTRACE(1, "SIP\tCould not write to " << transportAddress << " - " << transport->GetErrorText());
     Release(EndedByTransportFail);
@@ -1480,8 +1482,8 @@ void SIPConnection::OnReceivedINVITE(SIP_PDU & request)
       }
 
       // #2 - Different "dialog" determined by the tags in the to and from fields indicate forking
-      if (requestMIME.GetFieldParameter("From", "tag") != requestFromTag ||
-          requestMIME.GetFieldParameter("To",   "tag") != requestToTag) {
+      if (originalMIME.GetFieldParameter("From", "tag") != requestFromTag ||
+          originalMIME.GetFieldParameter("To",   "tag") != requestToTag) {
         PTRACE(3, "SIP\tIgnoring forked INVITE from " << request.GetURI());
         SIP_PDU response(request, SIP_PDU::Failure_LoopDetected);
         response.GetMIME().SetProductInfo(endpoint.GetUserAgent(), GetProductInfo());
@@ -1885,25 +1887,33 @@ PBoolean SIPConnection::OnReceivedAuthenticationRequired(SIPTransaction & transa
     return false;
   }
 
-  SIPURL proxy = endpoint.GetProxy();
-
    // Try to find authentication parameters for the given realm,
   // if not, use the proxy authentication parameters (if any)
-  PString realm, user, password;
-  if (endpoint.GetAuthentication(newAuth->GetAuthRealm(), realm, user, password)) {
+  PString realm, username, password;
+  if (endpoint.GetAuthentication(newAuth->GetAuthRealm(), realm, username, password)) {
     PTRACE (3, "SIP\tFound auth info for realm " << newAuth->GetAuthRealm());
-    newAuth->SetUsername(user);
-    newAuth->SetPassword(password);
   }
-  else if (!proxy.IsEmpty()) {
-    PTRACE (3, "SIP\tNo auth info for realm " << newAuth->GetAuthRealm() << ", using proxy auth");
-    newAuth->SetUsername(proxy.GetUserName());
-    newAuth->SetPassword(proxy.GetPassword());
-  } 
   else {
-    PTRACE (3, "SIP\tNo auth info for realm " << newAuth->GetAuthRealm());
+    SIPURL proxy = endpoint.GetProxy();
+    if (proxy.IsEmpty()) {
+      PTRACE (3, "SIP\tNo auth info for realm " << newAuth->GetAuthRealm());
+      delete newAuth;
+      return false;
+    }
+
+    PTRACE (3, "SIP\tNo auth info for realm " << newAuth->GetAuthRealm() << ", using proxy auth");
+    username = proxy.GetUserName();
+    password = proxy.GetPassword();
+  } 
+
+  newAuth->SetUsername(username);
+  newAuth->SetPassword(password);
+
+  // check to see if this is a follow-on from the last authentication scheme used
+  if (authentication != NULL && *newAuth == *authentication) {
+    PTRACE(1, "SIP\tAuthentication already performed using current credentials, not trying again.");
     delete newAuth;
-    return PFalse;
+    return false;
   }
 
   // Restart the transaction with new authentication info
@@ -2438,7 +2448,7 @@ PBoolean SIPConnection::OnMediaControlXML(SIP_PDU & request)
   else {
     PTRACE(3, "SIP\tPictureFastUpdate received");
     if (LockReadWrite()) {
-      OpalMediaStreamPtr encodingStream = GetMediaStream(OpalMediaFormat::DefaultVideoSessionID, PTrue);
+      OpalMediaStreamPtr encodingStream = GetMediaStream(OpalMediaType::Video(), true);
       if (encodingStream == NULL){
         PTRACE(3, "SIP\tNo video stream to update");
       } else {
