@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21062 $
+ * $Revision: 21311 $
  * $Author: rjongbloed $
- * $Date: 2008-09-18 11:41:40 +0000 (Thu, 18 Sep 2008) $
+ * $Date: 2008-10-13 08:13:15 +0000 (Mon, 13 Oct 2008) $
  */
 
 #include <ptlib.h>
@@ -66,7 +66,8 @@ SIPEndPoint::SIPEndPoint(OpalManager & mgr)
 #ifdef _MSC_VER
 #pragma warning(disable:4355)
 #endif
-  , m_interfaceMonitor(*this)
+  , m_highPriorityMonitor(*this, HighPriority)
+  , m_lowPriorityMonitor(*this, LowPriority)
 #ifdef _MSC_VER
 #pragma warning(default:4355)
 #endif
@@ -193,7 +194,7 @@ void SIPEndPoint::NATBindingRefresh(PTimer &, INT)
         case Options: 
           {
             SIPOptions options(*this, *transport, SIPURL(transport->GetRemoteAddress()).GetHostName());
-            options.Write(*transport, transport->GetRemoteAddress());
+            options.Write(*transport);
           }
           break;
 
@@ -504,7 +505,8 @@ bool SIPEndPoint::OnReceivedConnectionlessPDU(OpalTransport & transport, SIP_PDU
       break;
 
     case SIP_PDU::Method_ACK :
-      // If we receive an ACK outside of the context of a connection, ignore it.
+    case SIP_PDU::Method_BYE :
+      // If we receive an ACK or BYE outside of the context of a connection, ignore it.
       SendResponse(SIP_PDU::Failure_TransactionDoesNotExist, transport, *pdu);
       return false;
 
@@ -536,11 +538,8 @@ void SIPEndPoint::OnReceivedResponse(SIPTransaction & transaction, SIP_PDU & res
       || transaction.GetMethod() == SIP_PDU::Method_SUBSCRIBE
       || transaction.GetMethod() == SIP_PDU::Method_PUBLISH
       || transaction.GetMethod() == SIP_PDU::Method_MESSAGE) {
-
-    PString callID = transaction.GetMIME().GetCallID ();
-
-    // Have a response to the REGISTER/SUBSCRIBE/MESSAGE, 
-    handler = activeSIPHandlers.FindSIPHandlerByCallID (callID, PSafeReadOnly);
+    // Have a response to various non-INVITE messages
+    handler = activeSIPHandlers.FindSIPHandlerByCallID(transaction.GetMIME().GetCallID(), PSafeReadWrite);
     if (handler == NULL) 
       return;
   }
@@ -902,7 +901,7 @@ bool SIPEndPoint::Register(const SIPRegister::Params & params)
             "   minRetry=" << params.m_minRetryTime << "\n"
             "   maxRetry=" << params.m_maxRetryTime);
   PSafePtr<SIPRegisterHandler> handler = PSafePtrCast<SIPHandler, SIPRegisterHandler>(
-          activeSIPHandlers.FindSIPHandlerByUrl(params.m_addressOfRecord, SIP_PDU::Method_REGISTER, PSafeReadOnly));
+          activeSIPHandlers.FindSIPHandlerByUrl(params.m_addressOfRecord, SIP_PDU::Method_REGISTER, PSafeReadWrite));
 
   // If there is already a request with this URL and method, 
   // then update it with the new information
@@ -911,6 +910,7 @@ bool SIPEndPoint::Register(const SIPRegister::Params & params)
   else {
     // Otherwise create a new request with this method type
     handler = CreateRegisterHandler(params);
+    handler.SetSafetyMode(PSafeReadWrite);
     activeSIPHandlers.Append(handler);
   }
 
@@ -1324,8 +1324,8 @@ void SIPEndPoint::SIP_PDU_Thread::Main()
 }
 
 
-SIPEndPoint::InterfaceMonitor::InterfaceMonitor(SIPEndPoint & ep)
-  : PInterfaceMonitorClient(30)  // Low priority, after the bundled socket has been done
+SIPEndPoint::InterfaceMonitor::InterfaceMonitor(SIPEndPoint & ep, PINDEX priority)
+  : PInterfaceMonitorClient(priority) 
   , m_endpoint(ep)
 {
 }
@@ -1333,20 +1333,55 @@ SIPEndPoint::InterfaceMonitor::InterfaceMonitor(SIPEndPoint & ep)
         
 void SIPEndPoint::InterfaceMonitor::OnAddInterface(const PIPSocket::InterfaceEntry &)
 {
-  for (PSafePtr<SIPHandler> handler(m_endpoint.activeSIPHandlers, PSafeReadOnly); handler != NULL; ++handler) {
-    if (handler->GetState() == SIPHandler::Unavailable)
-      handler->SendRequest(SIPHandler::Restoring);
+  if (priority == SIPEndPoint::LowPriority) {
+    for (PSafePtr<SIPHandler> handler(m_endpoint.activeSIPHandlers, PSafeReadOnly); handler != NULL; ++handler) {
+      if (handler->GetState() == SIPHandler::Unavailable)
+        handler->SendRequest(SIPHandler::Restoring);
+    }
+  } else {
+    // special case if interface filtering is used: A new interface may 'hide' the old interface.
+    // If this is the case, remove the transport interface. 
+    //
+    // There is a race condition: If the transport interface binding is cleared AFTER
+    // PMonitoredSockets::ReadFromSocket() is interrupted and starts listening again,
+    // the transport will still listen on the old interface only. Therefore, clear the
+    // socket binding BEFORE the monitored sockets update their interfaces.
+    if (PInterfaceMonitor::GetInstance().HasInterfaceFilter()) {
+      for (PSafePtr<SIPHandler> handler(m_endpoint.activeSIPHandlers, PSafeReadOnly); handler != NULL; ++handler) {
+        OpalTransport *transport = handler->GetTransport();
+        if (transport != NULL) {
+          PString iface = transport->GetInterface();
+          if (iface.IsEmpty()) // not connected
+            continue;
+          
+          PIPSocket::Address addr;
+          if (!transport->GetRemoteAddress().GetIpAddress(addr))
+            continue;
+          
+          PStringArray ifaces = GetInterfaces(PFalse, addr);
+          
+          if (ifaces.GetStringsIndex(iface) == P_MAX_INDEX) { // original interface no longer available
+            transport->SetInterface(PString::Empty());
+            handler->SetState(SIPHandler::Unavailable);
+          }
+        }
+      }
+    }
   }
 }
 
 
 void SIPEndPoint::InterfaceMonitor::OnRemoveInterface(const PIPSocket::InterfaceEntry & entry)
 {
-  for (PSafePtr<SIPHandler> handler(m_endpoint.activeSIPHandlers, PSafeReadOnly); handler != NULL; ++handler) {
-    if (handler->GetState() == SIPHandler::Subscribed &&
-        handler->GetTransport() != NULL &&
-        handler->GetTransport()->GetInterface().Find(entry.GetName()) != P_MAX_INDEX)
-      handler->SendRequest(SIPHandler::Refreshing);
+  if (priority == SIPEndPoint::LowPriority) {
+    for (PSafePtr<SIPHandler> handler(m_endpoint.activeSIPHandlers, PSafeReadOnly); handler != NULL; ++handler) {
+      if (handler->GetState() == SIPHandler::Subscribed &&
+          handler->GetTransport() != NULL &&
+          handler->GetTransport()->GetInterface().Find(entry.GetName()) != P_MAX_INDEX) {
+        handler->GetTransport()->SetInterface(PString::Empty());
+        handler->SendRequest(SIPHandler::Refreshing);
+      }
+    }
   }
 }
 
